.. include:: /_includes/wip_prolog.rst

:mod:`stix.extensions.identity.ciq_identity_3_0` Module
=======================================================

.. module:: stix.extensions.identity.ciq_identity_3_0

Classes
-------

.. autoclass:: CIQIdentity3_0Instance
	:show-inheritance:
	:members:

.. autoclass:: STIXCIQIdentity3_0
	:show-inheritance:
	:members:

.. autoclass:: Address
	:show-inheritance:
	:members:

.. autoclass:: AdministrativeArea
	:show-inheritance:
	:members:

.. autoclass:: _BaseNameElement
	:show-inheritance:
	:members:

.. autoclass:: ContactNumber
	:show-inheritance:
	:members:

.. autoclass:: ContactNumberElement
	:show-inheritance:
	:members:

.. autoclass:: Country
	:show-inheritance:
	:members:

.. autoclass:: ElectronicAddressIdentifier
	:show-inheritance:
	:members:

.. autoclass:: FreeTextAddress
	:show-inheritance:
	:members:

.. autoclass:: FreeTextLine
	:show-inheritance:
	:members:

.. autoclass:: Language
	:show-inheritance:
	:members:

.. autoclass:: NameElement
	:show-inheritance:
	:members:

.. autoclass:: NameLine
	:show-inheritance:
	:members:

.. autoclass:: OrganisationInfo
	:show-inheritance:
	:members:

.. autoclass:: OrganisationName
	:show-inheritance:
	:members:

.. autoclass:: OrganisationNameElement
	:show-inheritance:
	:members:

.. autoclass:: PartyName
	:show-inheritance:
	:members:

.. autoclass:: PersonName
	:show-inheritance:
	:members:

.. autoclass:: PersonNameElement
	:show-inheritance:
	:members:

.. autoclass:: SubDivisionName
	:show-inheritance:
	:members:

Constants
---------

.. autodata:: XML_NS_XPIL

.. autodata:: XML_NS_XNL

.. autodata:: XML_NS_XAL

.. autodata:: XML_NS_STIX_EXT
